SdkApplicantResponse class

Applicant payload from SDK applicant APIs (POST/GET .../applicants).

Constructors

SdkApplicantResponse({required String id, required String userId, required String customerIdentifier, String? fullName, String? email, String? phone, String? nationality, Map<String, dynamic>? address, String? status, String? mode, required DateTime createdAt, required DateTime updatedAt, String? kycWebUrl})
SdkApplicantResponse.fromJson(Map<String, dynamic> json)
factory

Properties

address Map<String, dynamic>?
final
createdAt DateTime
final
customerIdentifier String
final
email String?
final
fullName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
kycWebUrl String?
{base}/?id={id} — start KYC for this applicant in apex_kyc_web (verification uses /verify/... on the same field name in SdkVerificationResponse).
final
mode String?
final
nationality String?
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
updatedAt DateTime
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited