SdkKycStep enum

Steps in the SDK KYC flow

Inheritance
Available extensions

Values

documentTypeSelection → const SdkKycStep
creatingVerification → const SdkKycStep
capturingFront → const SdkKycStep
uploadingFront → const SdkKycStep
capturingBack → const SdkKycStep
uploadingBack → const SdkKycStep
livenessVerification → const SdkKycStep
kycWebPreparing → const SdkKycStep

Flutter Web: resolving applicant SdkApplicantResponse.kycWebUrl (no create verification yet).

kycWebEmbedded → const SdkKycStep

Flutter Web only: embedded apex_kyc_web (/?id= from applicant or /verify/ after create verification).

completed → const SdkKycStep

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SdkKycStep>
A constant List of the values in this enum, in order of their declaration.